EXPORTS
	__9CKeysDataP9CKeysData @ 1 NONAME R3UNUSED ; CKeysData::CKeysData(CKeysData *)
	ConstructL__11CPolicySpecP11CPolicySpec @ 2 NONAME R3UNUSED ; CPolicySpec::ConstructL(CPolicySpec *)
	ConstructL__11CPolicySpecR7TDesC16 @ 3 NONAME R3UNUSED ; CPolicySpec::ConstructL(TDesC16 &)
	ConstructL__13CSelectorListP13CSelectorListP11CSAPairList @ 4 NONAME R3UNUSED ; CSelectorList::ConstructL(CSelectorList *, CSAPairList *)
	ConstructL__14CKeysDataArrayP14CKeysDataArray @ 5 NONAME R3UNUSED ; CKeysDataArray::ConstructL(CKeysDataArray *)
	ConstructL__15CPolicySelectorP15CPolicySelector @ 6 NONAME R3UNUSED ; CPolicySelector::ConstructL(CPolicySelector *)
	ConstructL__15CSecurityPolicy @ 7 NONAME R3UNUSED ; CSecurityPolicy::ConstructL(void)
	ConstructL__15CSecurityPolicyP15CSecurityPolicy @ 8 NONAME R3UNUSED ; CSecurityPolicy::ConstructL(CSecurityPolicy *)
	ConstructL__16CIpSecurityPiecei @ 9 NONAME R3UNUSED ; CIpSecurityPiece::ConstructL(int)
	ConstructL__7CSAListP7CSAList @ 10 NONAME R3UNUSED ; CSAList::ConstructL(CSAList *)
	Construct__11CPolicySpec @ 11 NONAME R3UNUSED ; CPolicySpec::Construct(void)
	Construct__13CSelectorListi @ 12 NONAME R3UNUSED ; CSelectorList::Construct(int)
	Construct__14CKeysDataArrayi @ 13 NONAME R3UNUSED ; CKeysDataArray::Construct(int)
	Construct__15CPolicySelector @ 14 NONAME R3UNUSED ; CPolicySelector::Construct(void)
	Construct__7CSAListi @ 15 NONAME R3UNUSED ; CSAList::Construct(int)
	CopyL__14CKeysDataArrayP14CKeysDataArray @ 16 NONAME R3UNUSED ; CKeysDataArray::CopyL(CKeysDataArray *)
	Empty__14CKeysDataArray @ 17 NONAME R3UNUSED ; CKeysDataArray::Empty(void)
	FindSpec__15CSecurityPolicyRC6TDesC8 @ 18 NONAME R3UNUSED ; CSecurityPolicy::FindSpec(TDesC8 const &)
	NewL__11CPolicySpec @ 19 NONAME R3UNUSED ; CPolicySpec::NewL(void)
	NewL__11CPolicySpecP11CPolicySpec @ 20 NONAME R3UNUSED ; CPolicySpec::NewL(CPolicySpec *)
	NewL__11CPolicySpecR7TDesC16 @ 21 NONAME R3UNUSED ; CPolicySpec::NewL(TDesC16 &)
	NewL__13CSelectorListP13CSelectorListP11CSAPairList @ 22 NONAME R3UNUSED ; CSelectorList::NewL(CSelectorList *, CSAPairList *)
	NewL__13CSelectorListi @ 23 NONAME R3UNUSED ; CSelectorList::NewL(int)
	NewL__14CKeysDataArrayP14CKeysDataArray @ 24 NONAME R3UNUSED ; CKeysDataArray::NewL(CKeysDataArray *)
	NewL__14CKeysDataArrayi @ 25 NONAME R3UNUSED ; CKeysDataArray::NewL(int)
	NewL__15CPolicySelector @ 26 NONAME R3UNUSED ; CPolicySelector::NewL(void)
	NewL__15CPolicySelectorP15CPolicySelector @ 27 NONAME R3UNUSED ; CPolicySelector::NewL(CPolicySelector *)
	NewL__7CSAListP7CSAList @ 28 NONAME R3UNUSED ; CSAList::NewL(CSAList *)
	NewL__7CSAListi @ 29 NONAME R3UNUSED ; CSAList::NewL(int)
	ParseAndIgnoreIKEL__12TIpSecParserP16CIpSecurityPiece @ 30 NONAME R3UNUSED ; TIpSecParser::ParseAndIgnoreIKEL(CIpSecurityPiece *)
	ParseL__10TKeyParserP14CKeysDataArray @ 31 NONAME R3UNUSED ; TKeyParser::ParseL(CKeysDataArray *)
	ParseL__12TIpSecParserP16CIpSecurityPiece @ 32 NONAME R3UNUSED ; TIpSecParser::ParseL(CIpSecurityPiece *)
	ParseL__13TPolicyParserP16CIpSecurityPiece @ 33 NONAME R3UNUSED ; TPolicyParser::ParseL(CIpSecurityPiece *)
	SetInfoL__16CIpSecurityPieceRC7TDesC16 @ 34 NONAME R3UNUSED ; CIpSecurityPiece::SetInfoL(TDesC16 const &)
	UseSA__15CPolicySelectorP11CPolicySpecP9TInetAddr @ 35 NONAME R3UNUSED ; CPolicySelector::UseSA(CPolicySpec *, TInetAddr *)
	Write__10TKeyParserP14CKeysDataArrayR5RFile @ 36 NONAME R3UNUSED ; TKeyParser::Write(CKeysDataArray *, RFile &)
	Write__12TIpSecParserP16CIpSecurityPieceRP6HBufC8 @ 37 NONAME R3UNUSED ; TIpSecParser::Write(CIpSecurityPiece *, HBufC8 *&)
	Write__13TPolicyParserP15CSecurityPolicyRP6HBufC8i @ 38 NONAME R3UNUSED ; TPolicyParser::Write(CSecurityPolicy *, HBufC8 *&, int)
	"_._11CPolicySpec" @ 39 NONAME R3UNUSED ; CPolicySpec::~CPolicySpec(void)
	"_._14CKeysDataArray" @ 40 NONAME R3UNUSED ; CKeysDataArray::~CKeysDataArray(void)
	"_._15CPolicySelector" @ 41 NONAME R3UNUSED ; CPolicySelector::~CPolicySelector(void)
	"_._16CIpSecurityPiece" @ 42 NONAME R3UNUSED ; CIpSecurityPiece::~CIpSecurityPiece(void)
	__10TKeyParserRC7TDesC16 @ 43 NONAME R3UNUSED ; TKeyParser::TKeyParser(TDesC16 const &)
	__12TIpSecParserRC7TDesC16 @ 44 NONAME R3UNUSED ; TIpSecParser::TIpSecParser(TDesC16 const &)
	__13TPolicyParserRC7TDesC16 @ 45 NONAME R3UNUSED ; TPolicyParser::TPolicyParser(TDesC16 const &)
	__15CSecurityPolicy @ 46 NONAME R3UNUSED ; CSecurityPolicy::CSecurityPolicy(void)
	__9CKeysData @ 47 NONAME R3UNUSED ; CKeysData::CKeysData(void)
	BufferAppend__13TPolicyParserRP6HBufC8RC6TDesC8 @ 48 NONAME R3UNUSED ; TPolicyParser::BufferAppend(HBufC8 *&, TDesC8 const &)

